@@ -1,8 +1,6 @@
-use std::fs::File;
-use std::io::prelude::*;
-
 use eyre::Result;
 use structopt::StructOpt;
+use tokio::{fs::File, io::AsyncWriteExt};
 
 use atuin_client::api_client;
 use atuin_client::settings::Settings;
@@ -20,7 +18,7 @@ pub struct Cmd {
     pub password: Option<String>,
 }
 
-pub fn run(
+pub async fn run(
     settings: &Settings,
     username: &Option<String>,
     email: &Option<String>,
@@ -32,11 +30,11 @@ pub fn run(
     let password = or_user_input(password, "password");
 
     let session =
-        api_client::register(settings.sync_address.as_str(), &username, &email, &password)?;
+        api_client::register(settings.sync_address.as_str(), &username, &email, &password).await?;
 
     let path = settings.session_path.as_str();
-    let mut file = File::create(path)?;
-    file.write_all(session.session.as_bytes())?;
+    let mut file = File::create(path).await?;
+    file.write_all(session.session.as_bytes()).await?;
 
     // Create a new key, and save it to disk
     let _key = atuin_client::encryption::new_key(settings)?;
